@@ -381,7 +381,7 @@ class Strategy:
                 ret_all[self.benchmark].dropna().iloc[0]
         else:
             self.benchmark = 'benchmark'
-            ret_all[self.benchmark] = self.fixed_rate
+            ret_all[self.benchmark] = np.exp(np.log1p(self.fixed_rate) / 252) - 1
             ret_all.iloc[0, -1] = 0.0
             ret_all[self.benchmark] = (1 + ret_all[self.benchmark]).cumprod()
 
